@@ -13,7 +13,6 @@
 #if !defined(__END_DECLS)
 # define __END_DECLS
 #endif
-#include <sys/types.h>
 #define HAVE_ARC4RANDOM 1
 #define HAVE_CAPSICUM 0
 #define HAVE_ERR 1
@@ -25,17 +24,16 @@
 #define HAVE_MEMRCHR 1
 #define HAVE_MEMSET_S 0
 #define HAVE_PATH_MAX 1
-#define HAVE_PLEDGE 0
+#define HAVE_PLEDGE 1
 #define HAVE_PROGRAM_INVOCATION_SHORT_NAME 0
 #define HAVE_REALLOCARRAY 1
-#define HAVE_RECALLOCARRAY 0
+#define HAVE_RECALLOCARRAY 1
 #define HAVE_SANDBOX_INIT 0
 #define HAVE_SECCOMP_FILTER 0
 #define HAVE_SOCK_NONBLOCK 1
 #define HAVE_STRLCAT 1
 #define HAVE_STRLCPY 1
 #define HAVE_STRTONUM 1
-#define HAVE_SYSTRACE 1
+#define HAVE_SYSTRACE 0
 #define HAVE_ZLIB 1
 #define HAVE___PROGNAME 1
-extern void *recallocarray(void *, size_t, size_t, size_t);
