@@ -1,4 +1,4 @@
-/*	$Id: document.c,v 1.107 2017/10/17 22:10:09 kristaps Exp $ */
+/*	$Id: document.c,v 1.108 2018/04/18 19:07:00 kristaps Exp $ */
 /*
  * Copyright (c) 2008, Natacha Porté
  * Copyright (c) 2011, Vicent Martí
@@ -3528,9 +3528,11 @@ parse_metadata(hdoc *doc, const char *data, size_t sz)
 			break;
 		}
 
-		/* Consume colon, value, then on to next token. */
+		/* Pass colon, space, value, then to next token. */
 
 		i++;
+		while (isspace((unsigned char)data[i]))
+			i++;
 		val = parse_metadata_val(&data[i], sz - i, &valsz);
 		m->value = xstrndup(val, valsz);
 		pos = i + valsz + 1;
